@@ -5,7 +5,7 @@ from django.apps import AppConfig
 
 
 class TasksConfig(AppConfig):
-    name = "tasks"
+    name = "django_cloudtask"
 
     def ready(self):
         # go through all apps and register tasks.
